#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-ghc
version:              0.4.15.1
visibility:           public
id:                   microlens-ghc-0.4.15.1-IAH2ejAowXtJjYrGb5ebmG
key:                  microlens-ghc-0.4.15.1-IAH2ejAowXtJjYrGb5ebmG
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/stevenfontanella/microlens
synopsis:             microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).

    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/stevenfontanella/microlens#readme on Github>.

category:             Data, Lenses
abi:                  6b8bdff8f8455512ea02ca7ecd8c0f2b
exposed:              True
exposed-modules:      Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microlens-ghc-0.4.15.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microlens-ghc-0.4.15.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microlens-ghc-0.4.15.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-ghc
hs-libraries:         HSmicrolens-ghc-0.4.15.1-IAH2ejAowXtJjYrGb5ebmG
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock

haddock-html:         /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

